@@ -1,14 +1,14 @@
 #!BPY
 
 """
-Name: 'Interactive Console'
-Blender: 237
+Name: 'Interactive Python Console'
+Blender: 245
 Group: 'System'
 Tooltip: 'Interactive Python Console'
 """
 
-__author__ = "Campbell Barton AKA Ideasman"
-__url__ = ["Author's homepage, http://members.iinet.net.au/~cpbarton/ideasman/", "blender", "elysiun", "Official Python site, http://www.python.org"]
+__author__ = "Campbell Barton aka ideasman42"
+__url__ = ["www.blender.org", "blenderartists.org", "www.python.org"]
 __bpydoc__ = """\
 This is an interactive console, similar to Python's own command line interpreter.  Since it is embedded in Blender, it has access to all Blender Python modules.
 
@@ -26,8 +26,6 @@ Usage:<br>
   - Ctrl + Enter: auto compleate based on variable names and modules loaded -- multiple choices popup a menu;<br>
   - Shift + Enter: multiline functions -- delays executing code until only Enter is pressed.
 """
-__author__ = "Campbell Barton AKA Ideasman"
-__url__ = ["http://members.iinet.net.au/~cpbarton/ideasman/", "blender", "elysiun"]
 
 # -------------------------------------------------------------------------- 
 # ***** BEGIN GPL LICENSE BLOCK ***** 
@@ -63,7 +61,7 @@ __LINE_HISTORY__ = 500
 
 global __FONT_SIZE__
 
-__FONT_SIZES__ = ( ('tiny', 10), ('small', 12), ('normal', 14), ('large', 16) )
+__FONT_SIZES__ = ( ('tiny', 10), ('small', 12), ('normalfix', 14), ('large', 16) )
 __FONT_SIZE__ = 2 # index for the list above, normal default.
 
 global __CONSOLE_LINE_OFFSET__
@@ -285,6 +283,8 @@ def runUserCode(__USER_CODE_STRING__):
 	# Try and run the user entered line(s)
 	try:
 		# Load all variabls from global dict to local space.
+		__TMP_VAR_NAME__ = __TMP_VAR__ = '' # so as not to raise an error when del'ing
+
 		for __TMP_VAR_NAME__, __TMP_VAR__ in __CONSOLE_VAR_DICT__.items():
 			exec('%s%s' % (__TMP_VAR_NAME__,'=__TMP_VAR__'))
 		del __TMP_VAR_NAME__
@@ -295,7 +295,8 @@ def runUserCode(__USER_CODE_STRING__):
 		
 		# Flush global dict, allow the user to remove items.
 		__CONSOLE_VAR_DICT__ = {}
-		
+
+		__TMP_VAR_NAME__ = '' # so as not to raise an error when del'ing	
 		# Write local veriables to global __CONSOLE_VAR_DICT__
 		for __TMP_VAR_NAME__ in dir():
 			if	__TMP_VAR_NAME__ != '__FILE_LIKE_STRING__' and\
@@ -419,9 +420,13 @@ def handle_event(evt, val):
 		global histIndex, cmdBuffer
 		if abs(histIndex)+1 >= len(cmdBuffer):
 			histIndex = -1
+		histIndex_orig = histIndex
 		histIndex -= 1
-		while cmdBuffer[histIndex].type != 0 and abs(histIndex) < len(cmdBuffer):
+		
+		while	(cmdBuffer[histIndex].type != 0 and abs(histIndex) < len(cmdBuffer)) or \
+				( cmdBuffer[histIndex].cmd == cmdBuffer[histIndex_orig].cmd):
 			histIndex -= 1
+			
 		if cmdBuffer[histIndex].type == 0: # we found one
 			cmdBuffer[-1].cmd = cmdBuffer[histIndex].cmd			
 	
@@ -429,9 +434,13 @@ def handle_event(evt, val):
 		global histIndex, cmdBuffer
 		if histIndex >= -2:
 			histIndex = -len(cmdBuffer)
+		histIndex_orig = histIndex
 		histIndex += 1
-		while cmdBuffer[histIndex].type != 0 and histIndex != -2:
+		while	(cmdBuffer[histIndex].type != 0 and histIndex != -2) or \
+				( cmdBuffer[histIndex].cmd == cmdBuffer[histIndex_orig].cmd):
+			
 			histIndex += 1
+			
 		if cmdBuffer[histIndex].type == 0: # we found one
 			cmdBuffer[-1].cmd = cmdBuffer[histIndex].cmd
 	
@@ -715,6 +724,15 @@ def draw_gui():
 		else:  
 			BGL.glColor3f(1, 1, 0)
 		
+		if consoleLineIdx == 1: # user input
+			BGL.glRasterPos2i(margin, (__FONT_SIZES__[__FONT_SIZE__][1] * (consoleLineIdx-__CONSOLE_LINE_OFFSET__)) - 8)
+			Draw.Text(cmdBuffer[-consoleLineIdx].cmd, __FONT_SIZES__[__FONT_SIZE__][0])		
+		else:
+			BGL.glRasterPos2i(margin, (__FONT_SIZES__[__FONT_SIZE__][1] * ((consoleLineIdx-__CONSOLE_LINE_OFFSET__)+wrapLineIndex)) - 8)
+			Draw.Text(cmdBuffer[-consoleLineIdx].cmd, __FONT_SIZES__[__FONT_SIZE__][0])
+
+		# Wrapping is totally slow, can even hang blender - dont do it!
+		'''
 		if consoleLineIdx == 1: # NEVER WRAP THE USER INPUT
 			BGL.glRasterPos2i(margin, (__FONT_SIZES__[__FONT_SIZE__][1] * (consoleLineIdx-__CONSOLE_LINE_OFFSET__)) - 8)
 			# BUG, LARGE TEXT DOSENT DISPLAY
@@ -751,7 +769,7 @@ def draw_gui():
 				
 				BGL.glRasterPos2i(margin, (__FONT_SIZES__[__FONT_SIZE__][1] * ((consoleLineIdx-__CONSOLE_LINE_OFFSET__)+wrapLineIndex)) - 8)
 				Draw.Text(cmdBuffer[-consoleLineIdx].cmd, __FONT_SIZES__[__FONT_SIZE__][0])
-		
+		'''
 		consoleLineIdx += 1
 			
 
@@ -774,16 +792,25 @@ histIndex = cursor = -1 # How far back from the first letter are we? - in curren
 
 # Autoexec, startup code.
 scriptDir = Get('scriptsdir')
+console_autoexec = None
 if scriptDir:
-	if scriptDir.endswith(Blender.sys.sep):
+	if not scriptDir.endswith(Blender.sys.sep):
 		scriptDir += Blender.sys.sep
 	
 	console_autoexec  = '%s%s' % (scriptDir, 'console_autoexec.py')
 
 	if not sys.exists(console_autoexec):
 		# touch the file
-		cmdBuffer.append(cmdLine('...console_autoexec.py not found, making new in scripts dir', 1, None))
-		open(console_autoexec, 'w').close()
+		try:
+			open(console_autoexec, 'w').close()
+			cmdBuffer.append(cmdLine('...console_autoexec.py not found, making new in scripts dir', 1, None))
+		except:
+			cmdBuffer.append(cmdLine('...console_autoexec.py could not write, this is ok', 1, None))
+			scriptDir = None # make sure we only use this for console_autoexec.py
+	
+	if not sys.exists(console_autoexec):
+		console_autoexec = None
+	
 	else:
 		cmdBuffer.append(cmdLine('...Using existing console_autoexec.py in scripts dir', 1, None))
 
@@ -797,7 +824,8 @@ def include_console(includeFile):
 	
 	# Execute an external py file as if local
 	exec(include(includeFile))
-	
+
+def standard_imports():
 	# Write local to global __CONSOLE_VAR_DICT__ for reuse,
 	for ls in (dir(), dir(Blender)):
 		for __TMP_VAR_NAME__ in ls:
@@ -805,10 +833,12 @@ def include_console(includeFile):
 			exec('%s%s' % ('__CONSOLE_VAR_DICT__[__TMP_VAR_NAME__]=', __TMP_VAR_NAME__))
 	
 	exec('%s%s' % ('__CONSOLE_VAR_DICT__["bpy"]=', 'bpy'))
-	
-if scriptDir:
+
+if scriptDir and console_autoexec:
 	include_console(console_autoexec) # pass the blender module
 
+standard_imports() # import Blender and bpy
+
 #-end autoexec-----------------------------------------------------------------#
 
 
@@ -822,4 +852,4 @@ def main():
 	Draw.Register(draw_gui, handle_event, handle_button_event)
 
 if __name__ == '__main__':
-	main()
\ No newline at end of file
+	main()
